% value of GM for Earth
GM = 3.986004418e14;

% semi-major axis
a = 1.e7

% eccentricity
e = 0.95

% Period, from Kepler's 3rd Law
P = sqrt(4 * pi^2 * a^3 / GM)
% time-step of orbit
N = 100;
dt = P/N;

% initial state-vector
xv0 = zeros(6,1);
% place planet on x-axis
% use form of ellipse
xv0(1,1) = a*(1+e);
% velocity is in plus-y direction
% use energy conservation
xv0(5,1) = sqrt(GM*(2. / xv0(1,1) - 1. / a));

% set the initial plot
hold off;
close all;
scrsz = get(0,'ScreenSize');
figure1 = figure('Position',[0,scrsz(4)-512,512,512])

% plot an ellipse of the correct shape
ph = 0:pi/100.:2*pi;
r = a*(1-e^2) ./ (1-e*cos(ph));
xell = r .* cos(ph);
yell = r .* sin(ph);
plot(xell,yell,'-r');

% rescale the axes
axis([-a*(1-e),a*(1+e),-a,a]);

% label the axes
xlabel('x position (meters)');
ylabel('y position (meters)');
title('Earth Centered Orbit');

% set for overplotting
hold on;

% plot an "Earth" (not to scale)
R_E = 6.738e6;
plot(R_E .* cos(ph),R_E * sin(ph),'-b','LineWidth',2);

% Set the tolerances of the orbit integration
options = odeset('RelTol',5.e-8,'AbsTol',a*5.e-9);

% integrate the orbit
t = zeros(N,1);
xv = zeros(N,6);
for i = 1:N
   [ti,xvi] = ode45(@orbitfunc_complete,[0,dt],xv0,options);
   nout = size(ti);
   t(i) = i*dt;
   xv(i,:) = xvi(nout(1),:);
   plot(xv(i,1),xv(i,2),'.b');
   xv0(:,1) = xv(i,:);
   pause(0.05);
end

hold off;

% verify that energy is conserved
figure2 = figure;
Energy = 0.5*sum(xv(:,4:6).^2,2) - GM ./ sqrt(sum(xv(:,1:3).^2,2));

E0 = -GM/(2*a);
plot(t,Energy/E0)
axis([0,P,0,1.1]);
xlabel('time');
ylabel('Energy/Energy_0');
title('Earth Centered Orbit');